#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-yaml
version:              1.2.2
visibility:           public
id:                   dhall-yaml-1.2.2-Euwn979dvza50BzJTDbbXY
key:                  dhall-yaml-1.2.2-Euwn979dvza50BzJTDbbXY
license:              GPL-3.0-only
copyright:            2019 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  f450cadda7eb57984fe9472eeff76948
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-8.10.2/site-local/dhall-yaml-1.2.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/dhall-yaml-1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/dhall-yaml-1.2.2
hs-libraries:         HSdhall-yaml-1.2.2-Euwn979dvza50BzJTDbbXY
depends:
    HsYAML-0.2.1.0-O7PZZX3c2kJX2yikr45ww
    HsYAML-aeson-0.2.0.0-KjZJHo4XU0Xd5QzNsyjf0
    aeson-1.5.4.1-KnFYQBtHaFk4DA2IEtMGGQ base-4.14.1.0
    bytestring-0.10.10.0 dhall-1.35.0-7knuPqTZPi09p2bc7oBqLb
    dhall-json-1.7.2-5BS8fw1MCnoFaoC2gtuq9X
    optparse-applicative-0.15.1.0-6f95h1W3JYZMb1TESUiEr text-1.2.3.2
    vector-0.12.1.2-IO5RJnkQnAxDAG50LdixTd

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

